/* ========================================================================= */
/* HELPERS ================================================================= */
/* ========================================================================= */

getDevice = function() {
	return (
		window.getComputedStyle(
	    	document.querySelector('html'), ':before'
		).getPropertyValue('content')
	);
};

timeoutIds = {
	hiFemale: '',
	hiMale: '',
	goFemale: '',
	goMale: '',
	paFemale: '',
	paMale: '',
	tfFemale: '',
	tfMale: '',
	gcFemale: '',
	gcMale: '',
	fvFemale: '',
	fvMale: '',
	lzFemale: '',
	lzMale: ''
};

/* ========================================================================= */
/* FUNCTIONS =============================================================== */
/* ========================================================================= */

var siteHandler = {
	/**
	 * Carga un template con los datos que recibe como parámetro.
	 *
	 * @param  {String}   name    	- Nombre del fichero .hbs donde se encuentra el template
	 * @param  {String}   where   	- Selector CSS donde vamos a insertar el template
	 * @param  {Object}	  context	- Objeto con los datos que va a utilizar el template
	 * @param  {Boolean}  append  	- Si es true inserta el template al final de un contenedor para no borrar su contenido
	 * @param  {Function} callback  - Función de callback
	 */
	loadTemplate: function(name, where, context, append, func) {
		var location = where || '#' + name,
			data = context,
			template = JST['app/templates/' + name + '.hbs'],
			html = template(data),
			callback = func;

		if (append)
			$(location).append(html);
		else
			document.querySelector(location).innerHTML = html;
		if (func)
			callback();
	},
	/**
	 * Establece los eventos de la app
	 */
	setEvents: {
		// mostramos y activamos el contenido de cada 'person'
		activePersons: function(e){
			$('.person').off('click').on('click', function(event) {
				/* Act on the event */
				event.preventDefault();
				//vars
				var $person   = $(this),
					$parent   = $(this).parent(), // .person-picture
					$gparent  = $(this).parents('.person-wrapper'), // .person-wrapper
					$areas    = $parent.find('.area'),
					$lines    = $parent.find('.line-wrapper'),
					$icons    = $parent.find('.icon'),
					$text     = $parent.parent().find('.person-text'),
					personId  = $gparent.attr('data-id');

				if ($parent.hasClass('active')) {
					// Reset person! areas, text, icons and then lines...
					clearTimeout(timeoutIds[personId]); // Stop delay (avoid animation errors)
					$parent.removeClass('active');
					$areas.removeClass('flash').hide();
					$lines.removeClass('active');
					$icons.removeClass('zoomIn').hide();
					$parent.find('.icon .inactive').show();
					$text.removeClass('fadeIn').hide();
					$gparent.removeClass('active');
				}
				else {
					// Add class active to see the picture without grayscale
					$parent.addClass('active');

					// Add class active to show the text with a smooth transition
					$gparent.addClass('active');

					// Time to animate! first lines, then icons, and then text...
					$lines.addClass('active');
					timeoutIds[personId] = setTimeout(function() { // Delay (improve animation)
						$icons.addClass('zoomIn').show();
						$text.addClass('fadeIn').show();
					}, 900);

					// Events for icons
					$icons.find('.inactive').off('click').on('click', function(event) {
						/* Act on the event */
						var area = $(this).parent().data('area');
						$(this).parents('.person-pictures').find('.' + area).addClass('flash').show();
						$(this).hide();

						$icons.find('img').off('click').on('click', function(event) {
							/* Act on the event */
							var area = $(this).parent().data('area');
							$(this).parents('.person-pictures').find('.' + area).removeClass('flash').hide();
							$(this).parent().find('.inactive').show();
						});
					});
				}

			});
		},
		activeLegend: function() {
	      $('#infoIcon').on('click', function(event) {
	        event.preventDefault();
	        event.stopPropagation();
	        /* Act on the event */
	        siteHandler.loadTemplate($(this).data('modal'),'#nucleusModal .modal-body');
	          $('#nucleusModal').modal();
	      });
	    }
	},
	init: function() {
		//load template layout (header, grid, and site-canvas)
		this.loadTemplate('layout', '#mainWrapper', null, false, function(){
			siteHandler.loadTemplate('main');
			siteHandler.setEvents.activePersons();
		});
		siteHandler.setEvents.activeLegend();
	}
};

siteHandler.init();
